<?php
/**
 * ghasedak functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ghasedak
 */

if (!defined('_S_VERSION')) {
    // Replace the version number of the theme on each release.
    define('_S_VERSION', '1.0.0');
}
define('DW_GHASEDAK_IMG', get_template_directory_uri() . '/assets/img/');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ghasedak_setup()
{
    /*
        * Make theme available for translation.
        * Translations can be filed in the /languages/ directory.
        * If you're building a theme based on ghasedak, use a find and replace
        * to change 'ghasedak' to the name of your theme in all the template files.
        */
    load_theme_textdomain('ghasedak', get_template_directory() . '/languages');

    // Add default posts and comments RSS feed links to head.
    add_theme_support('automatic-feed-links');

    /*
        * Let WordPress manage the document title.
        * By adding theme support, we declare that this theme does not use a
        * hard-coded <title> tag in the document head, and expect WordPress to
        * provide it for us.
        */
    add_theme_support('title-tag');

    /*
        * Enable support for Post Thumbnails on posts and pages.
        *
        * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
        */
    add_theme_support('post-thumbnails');
    add_image_size('related-posts', '389', '245', true);
    add_image_size('home-posts', '800', '450', true);
    // This theme uses wp_nav_menu() in one location.
    register_nav_menus(
        array(
            'primary_menu' => esc_html__('Primary Menu', 'ghasedak'),
        )
    );

    // Set up the WordPress core custom background feature.
    add_theme_support(
        'custom-background',
        apply_filters(
            'ghasedak_custom_background_args',
            array(
                'default-color' => 'ffffff',
                'default-image' => '',
            )
        )
    );

    // Add theme support for selective refresh for widgets.
    add_theme_support('customize-selective-refresh-widgets');

    /**
     * Add support for core custom logo.
     *
     * @link https://codex.wordpress.org/Theme_Logo
     */
    add_theme_support(
        'custom-logo',
        array(
            'height' => 150,
            'width' => 150,
            'flex-width' => false,
            'flex-height' => false,
        )
    );
    add_theme_support('post-formats', array('image', 'video', 'audio'));
}

add_action('after_setup_theme', 'ghasedak_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ghasedak_content_width()
{
    $GLOBALS['content_width'] = apply_filters('ghasedak_content_width', 640);
}

add_action('after_setup_theme', 'ghasedak_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ghasedak_widgets_init()
{
    register_sidebar(array(
            'name' => esc_html__('Post Sidebar', 'ghasedak'),
            'id' => 'single-widget',
            'description' => esc_html__('Post Sidebar', 'ghasedak'),
            'before_widget' => '<section class="sidebar-widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3>',
            'after_title' => '</h3>'
        )
    );
    register_sidebar(array(
            'name' => esc_html__('Page Sidebar', 'ghasedak'),
            'id' => 'page-widget',
            'description' => esc_html__('Page Sidebar', 'ghasedak'),
            'before_widget' => '<section class="sidebar-widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3>',
            'after_title' => '</h3>'
        )
    );

    register_sidebar(array(
            'name' => esc_html__('Footer', 'ghasedak'),
            'id' => 'footer-widget',
            'description' => esc_html__('Footer Widget', 'ghasedak'),
            'before_widget' => '<section class="footer-widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3>',
            'after_title' => '</h3>'
        )
    );
}

add_action('widgets_init', 'ghasedak_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function ghasedak_scripts()
{
    wp_enqueue_style('ghasedak-style', get_stylesheet_uri(), array(), _S_VERSION);
    wp_enqueue_style('icons', get_template_directory_uri() . '/assets/css/icons.css', false, false);
    wp_style_add_data('ghasedak-style', 'ltr', 'replace');
    wp_enqueue_script('jquery');
    wp_enqueue_script('ghasedak-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);
    wp_enqueue_script('ghasedak', get_template_directory_uri() . '/assets/js/ghasedak.js', false, false);

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}

add_action('wp_enqueue_scripts', 'ghasedak_scripts');


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php'; ?>