<?php
/**
 * ghasedak Theme Customizer
 *
 * @package ghasedak
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ghasedak_customize_register($wp_customize)
{
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
    $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

    if (isset($wp_customize->selective_refresh)) {
        $wp_customize->selective_refresh->add_partial(
            'blogname',
            array(
                'selector' => '.site-title a',
                'render_callback' => 'ghasedak_customize_partial_blogname',
            )
        );
        $wp_customize->selective_refresh->add_partial(
            'blogdescription',
            array(
                'selector' => '.site-description',
                'render_callback' => 'ghasedak_customize_partial_blogdescription',
            )
        );
    }
    $wp_customize->add_section(
        'ghasedak_main_settings', array(
            'title' => esc_html__('Home Settings', 'ghasedak'),
            'priority' => 100,
            'capability' => 'edit_theme_options',
        )
    );
    $wp_customize->add_section(
        'ghasedak_post_settings', array(
            'title' => esc_html__('Post Settings', 'ghasedak'),
            'priority' => 100,
            'capability' => 'edit_theme_options',
        )
    );
    $wp_customize->add_section(
        'ghasedak_theme_feature', array(
            'title' => esc_html__('Theme Feature', 'ghasedak'),
            'priority' => 101,
            'capability' => 'edit_theme_options',
        )
    );
    $wp_customize->add_section(
        'ghasedak_social_links', array(
            'title' => esc_html__('Social Media', 'ghasedak'),
            'priority' => 102,
            'capability' => 'edit_theme_options',
        )
    );

    //Settings
    $wp_customize->add_setting(
        'intro-header-setting', array(
        'default' => 'hide',
        'sanitize_callback' => 'esc_attr',
    ));
    $wp_customize->add_setting(
        'intro_avatar_animation', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    //
    $wp_customize->add_setting(
        'post_sidebar_settings', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'page_sidebar_settings', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'related_posts_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
//
    $wp_customize->add_setting(
        'thumbnail_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'author_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'category_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'date_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'comment_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'tags_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'comments_url_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'comments_cookie_setting', array(
            'default' => 'hide',
            'sanitize_callback' => 'esc_attr',
        )
    );

    $wp_customize->add_setting(
        'setting_instagram', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_facebook', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_twitter', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_youtube', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_wordpress', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_github', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_linkedin', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_mail', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    $wp_customize->add_setting(
        'setting_custom_link', array(
            'sanitize_callback' => 'esc_attr',
        )
    );
    //Controls
    $wp_customize->add_control(
        'intro-header-control', array(
            'type' => 'radio',
            'label' => esc_html__('Intro Header', 'ghasedak'),
            'section' => 'ghasedak_main_settings',
            'settings' => 'intro-header-setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'intro-avatar-control', array(
            'type' => 'radio',
            'label' => esc_html__('Avatar Animation', 'ghasedak'),
            'section' => 'ghasedak_main_settings',
            'settings' => 'intro_avatar_animation',
            'choices' => array(
                'show' => esc_html__('Enable', 'ghasedak'),
                'hide' => esc_html__('Disable', 'ghasedak')
            )
        )
    );
    //
    $wp_customize->add_control(
        'post_sidebar_control', array(
            'type' => 'radio',
            'label' => esc_html__('Post With Sidebar', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'post_sidebar_settings',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'page_sidebar_control', array(
            'type' => 'radio',
            'label' => esc_html__('Page With Sidebar', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'page_sidebar_settings',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'related_posts_control', array(
            'type' => 'radio',
            'label' => esc_html__('Related Posts', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'related_posts_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );//
    $wp_customize->add_control(
        'comments_url_control', array(
            'type' => 'radio',
            'label' => esc_html__('Comments Url Field', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'comments_url_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'comments_cookie_control', array(
            'type' => 'radio',
            'label' => esc_html__('Comments Cookie Field', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'comments_cookie_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );

    $wp_customize->add_control(
        'thumbnail_control', array(
            'type' => 'radio',
            'label' => esc_html__('Post Thumbnail', 'ghasedak'),
            'section' => 'ghasedak_theme_feature',
            'settings' => 'thumbnail_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'author_control', array(
            'type' => 'radio',
            'label' => esc_html__('Author', 'ghasedak'),
            'section' => 'ghasedak_theme_feature',
            'settings' => 'author_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'category_control', array(
            'type' => 'radio',
            'label' => esc_html__('Category', 'ghasedak'),
            'section' => 'ghasedak_theme_feature',
            'settings' => 'category_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'date_control', array(
            'type' => 'radio',
            'label' => esc_html__('Date', 'ghasedak'),
            'section' => 'ghasedak_theme_feature',
            'settings' => 'date_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'comment_control', array(
            'type' => 'radio',
            'label' => esc_html__('Comment', 'ghasedak'),
            'section' => 'ghasedak_theme_feature',
            'settings' => 'comment_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );
    $wp_customize->add_control(
        'tags_control', array(
            'type' => 'radio',
            'label' => esc_html__('Post Tags', 'ghasedak'),
            'section' => 'ghasedak_post_settings',
            'settings' => 'tags_setting',
            'choices' => array(
                'show' => esc_html__('Show', 'ghasedak'),
                'hide' => esc_html__('Hide', 'ghasedak')
            )
        )
    );

    $wp_customize->add_control(
        'insta_control', array(
            'type' => 'text',
            'label' => esc_html__('Instagram', 'ghasedak'),
            'section' => 'ghasedak_social_links',

            'settings' => 'setting_instagram',
        )
    );

    $wp_customize->add_control(
        'twitter_control', array(
            'type' => 'text',
            'label' => esc_html__('Twitter', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_twitter'
        )
    );
    $wp_customize->add_control(
        'facebook_control', array(
            'type' => 'text',
            'label' => esc_html__('Facebook', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_facebook'
        )
    );
    $wp_customize->add_control(
        'youtube_control', array(
            'type' => 'text',
            'label' => esc_html__('Youtube', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_youtube'
        )
    );
    $wp_customize->add_control(
        'wordpress_control', array(
            'type' => 'text',
            'label' => esc_html__('Wordpress', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_wordpress'
        )
    );
    $wp_customize->add_control(
        'github_control', array(
            'type' => 'text',
            'label' => esc_html__('Github', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_github'
        )
    );
    $wp_customize->add_control(
        'linkedin_control', array(
            'type' => 'text',
            'label' => esc_html__('Linkedin', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_linkedin'
        )
    );
    $wp_customize->add_control(
        'mail_control', array(
            'type' => 'text',
            'label' => esc_html__('Mail', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_mail'
        )
    );
    $wp_customize->add_control(
        'custom_link_control', array(
            'type' => 'text',
            'label' => esc_html__('Custom Link', 'ghasedak'),
            'section' => 'ghasedak_social_links',
            'settings' => 'setting_custom_link'
        )
    );
}

add_action('customize_register', 'ghasedak_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ghasedak_customize_partial_blogname()
{
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ghasedak_customize_partial_blogdescription()
{
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ghasedak_customize_preview_js()
{
    wp_enqueue_script('ghasedak-customizer', get_template_directory_uri() . '/js/customizer.js', array('customize-preview'), _S_VERSION, true);
}

add_action('customize_preview_init', 'ghasedak_customize_preview_js');
