<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package ghasedak
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function ghasedak_body_classes($classes)
{
    // Adds a class of hfeed to non-singular pages.
    if (!is_singular()) {
        $classes[] = 'hfeed';
    }

    // Adds a class of no-sidebar when there is no sidebar present.
    if (!is_active_sidebar('single')) {
        $classes[] = 'no-sidebar';
    }

    return $classes;
}

add_filter('body_class', 'ghasedak_body_classes');

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function ghasedak_pingback_header()
{
    if (is_singular() && pings_open()) {
        printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
    }
}

add_action('wp_head', 'ghasedak_pingback_header');
function dw_post_details()
{
    if (get_theme_mod('author_setting') == 'show'): ?>
        <span><?php esc_html_e('Author: ', 'ghasedak') ?><?php the_author(); ?></span>
    <?php endif;
    if (get_theme_mod('category_setting') == 'show'): ?>
        <span><?php esc_html_e('Posted on: ', 'ghasedak') ?><?php the_category('-'); ?></span>
    <?php endif;
    if (get_theme_mod('comment_setting') == 'show'): ?>
        <span><?php comments_number(__('No Comment', 'ghasedak'), esc_html__('1 Comment', 'ghasedak'), esc_html__('% Comments', 'ghasedak')); ?></span>
    <?php endif;
    if (get_theme_mod('date_setting') == 'show'): ?>
        <span><?php the_time(' Y/m/d') ?></span>
    <?php endif;
}

function dw_post_title()
{
    ?>
    <h2 class="dw-post-title">
        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
    </h2>
    <?php
}

function dw_social_links()
{
    if (get_theme_mod('setting_instagram')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_instagram')) ?>"
           title="<?php esc_html_e('Instagram Profile', 'ghasedak') ?>"
           class="instagram">
            <i class="icon-instagram"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_twitter')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_twitter')) ?>"
           title="<?php esc_html_e('Twitter  Profile', 'ghasedak') ?>"
           class="twitter">
            <i class="icon-twitter"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_facebook')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_facebook')) ?>"
           title="<?php esc_html_e('Facebook Profile', 'ghasedak') ?>"
           class="facebook">
            <i class="icon-facebook"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_youtube')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_youtube')) ?>"
           title="<?php esc_html_e('Youtube Profile', 'ghasedak') ?>"
           class="youtube">
            <i class="icon-youtube-play"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_wordpress')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_wordpress')) ?>"
           title="<?php esc_html_e('Wordpress Profile', 'ghasedak') ?>"
           class="wordpress">
            <i class="icon-wordpress"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_linkedin')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_linkedin')) ?>"
           title="<?php esc_html_e('Linkedin Profile', 'ghasedak') ?>"
           class="linkedin">
            <i class="icon-linkedin"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_github')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_github')) ?>"
           title="<?php esc_html_e('Github Profile', 'ghasedak') ?>"
           class="wordpress">
            <i class="icon-github-circled"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_mail')): ?>
        <a href="mailto:<?php echo esc_url(get_theme_mod('setting_mail')) ?>"
           title="<?php esc_html_e('Email', 'ghasedak') ?>"
           class="custom-link">
            <i class="icon-mail"></i>
        </a>
    <?php endif;
    if (get_theme_mod('setting_custom_link')): ?>
        <a href="<?php echo esc_url(get_theme_mod('setting_custom_link')) ?>"
           title="<?php esc_html_e('Link', 'ghasedak') ?>"
           class="custom-link">
            <i class="icon-link"></i>
        </a>
    <?php endif;
}

function dw_post_thumbnail()
{
    if (get_theme_mod('thumbnail_setting') == 'show'):
        if (has_post_thumbnail()): ?>
            <div class="dw-thumbnail">
                <a href="<?php the_permalink(); ?>">
                    <?php if (has_post_format('image')): ?>
                        <?php the_post_thumbnail(); ?>
                        <div class="image-format-title">
                            <span class="icon-picture" aria-hidden="true"></span>
                            <h2 class="image-title"><?php the_title(); ?></h2>
                            <div class="image-date">
                                <?php esc_html_e('Send Date:', 'ghasedak');
                                the_time(' Y/m/d') ?>
                            </div>
                        </div>
                    <?php else:
                        the_post_thumbnail('home-posts');
                    endif; ?>
                </a>
            </div>
        <?php endif; endif;
}

function dw_post_tags()
{
    if (get_theme_mod('tags_setting') == 'show'):
        if (has_tag()): ?>
            <div class="dw-tags">
                <?php the_tags('', ' ', ''); ?>
            </div>
        <?php endif;
    endif;
}

function dw_related_posts()
{
    if (get_theme_mod('related_posts_setting') == 'show'): ?>
        <div class="dw-wrapper">
            <div class="dw-post-hr"></div>
            <div class="dw-relatedposts">
                <?php
                global $post;
                $categories = get_the_category($post->ID);
                if ($categories):
                    $category_ids = array();
                    foreach ($categories as $category) {
                        $category_ids[] = $category->term_id;
                    }
                    $args = array(
                        'category__in' => $category_ids,
                        'post__not_in' => array($post->ID),
                        'posts_per_page' => 4,
                        'caller_get_posts' => 1
                    );
                    $related_posts = new wp_query($args);
                    if ($related_posts->have_posts()):
                        while ($related_posts->have_posts()):
                            $related_posts->the_post();
                            ?>
                            <article class="dw-reladetpost">
                                <a href="<?php the_permalink(); ?>" title="<?php the_title() ?>">
                                    <?php if (has_post_thumbnail()):
                                        the_post_thumbnail('related-posts');
                                    else:
                                        echo '<img src="' . DW_GHASEDAK_IMG . 'no-image.jpg" alt="بدون تصویر">';
                                    endif;
                                    ?>
                                    <h2><?php the_title() ?></h2>
                                </a>
                            </article>
                        <?php
                        endwhile;
                    endif;
                endif;
                ?>
            </div>
        </div>
    <?php endif;
    wp_reset_postdata();
}

function more_link()
{
    return ' <div class="dw-more"><a href="' . get_the_permalink() . '">' . esc_html__('CONTINUE READING', 'ghasedak') . '<span class="icon-down-open-mini"></span><span class="icon-down-open-mini"></span><span class="icon-down-open-mini"></span></a></div>';
}

add_filter('the_content_more_link', 'more_link');

function dw_pagination()
{
    if (get_the_posts_pagination()): ?>
        <div class="dw-post-hr"></div>
        <?php the_posts_pagination(array(
            'mid_size' => '2',
            'prev_next' => false,
        ));
    endif;
}

function dw_copyright_date()
{
    global $wpdb;
    $copyright_date = $wpdb->get_results("SELECT YEAR (MIN(post_date)) AS firstdate, YEAR (MAX(post_date)) AS lastdate FROM $wpdb->posts WHERE post_status = 'publish'");
    if ($copyright_date) {
        if ($copyright_date[0]->firstdate != $copyright_date[0]->lastdate) {
            echo $copyright = $copyright_date[0]->firstdate . ' - ' . $copyright_date[0]->lastdate;
        } else {
            echo $copyright_date[0]->firstdate;
        }
    }
}

add_action('template_redirect', 'dw_attachment_redirect');
function dw_attachment_redirect()
{
    global $post;
    if (is_attachment() && isset($post->post_parent) && is_numeric($post->post_parent) && ($post->post_parent != 0)) :
        wp_redirect(get_permalink($post->post_parent), 301);
        exit();
    endif;
}

add_filter('wp_list_comments_args', 'dw_filter_comment_list');
add_filter('comment_form_default_fields', 'dw_filter_input');
add_filter('comment_form_field_comment', 'dw_filter_comment_area');

function dw_filter_comment_list($args)
{
    $args['avatar_size'] = 70;

    return $args;
}

function dw_filter_input($fields)
{
    $fields['author'] = '<p class="comment-form-author"><input placeholder="' . esc_html__('Name (required)', 'ghasedak') . '" id="author" name="author" type="text" value="" size="30" maxlength="245" required="required"></p>';
    $fields['email'] = '<p class="comment-form-email"><input placeholder="' . esc_html__('Email (required)', 'ghasedak') . '" id="email" name="email" type="text" value="" size="30" maxlength="100" aria-describedby="email-notes" required="required"></p>';
    if (get_theme_mod('comments_url_setting') == 'show') {
        $fields['url'] = '<p class="comment-form-url"><input placeholder="' . esc_html__('Website', 'ghasedak') . '" id="url" name="url" type="text" value="" size="30" maxlength="245"></p>';
    } else {
        unset($fields['url']);
    }
    if (get_theme_mod('comments_cookie_setting') == 'hide') {
        unset($fields['cookies']);
    }
    return $fields;
}

function dw_filter_comment_area($field)
{
    return $field = '<p class="comment-form-comment"><textarea placeholder="' . esc_html__('Comment (required)', 'ghasedak') . '" id="comment" name="comment" cols="45" rows="8" maxlength="65525" required="required"></textarea></p>';
}


add_action('wp_dashboard_setup', 'wp_admin_dashboard_blog_widget');
function wp_admin_dashboard_blog_widget()
{
    global $wp_meta_boxes;
    wp_add_dashboard_widget('dashboard_dw_blog', esc_html__('Dangoweb Tutorials', 'ghasedak'), function () {
        wp_widget_rss_output(array(
            'url' => 'https://dangoweb.ir/feed/',
            'title' => esc_html__('Latest Posts', 'ghasedak'),
            'items' => 5,
            'show_summary' => 0,
            'show_author' => 0,
            'show_date' => 1
        ));
    });
}

add_action('wp_dashboard_setup', 'wp_admin_dashboard_product');
function wp_admin_dashboard_product()
{
    global $wp_meta_boxes;
    wp_add_dashboard_widget('dashboard_dw_product', esc_html__('Dangoweb Products', 'ghasedak'), function () {
        wp_widget_rss_output(array(
            'url' => 'https://dangoweb.ir/feed/?post_type=product',
            'title' => esc_html__('Latest Products', 'ghasedak'),
            'items' => 5,
            'show_summary' => 0,
            'show_author' => 0,
            'show_date' => 1
        ));
    });
}
