<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Ghasedak
 */

get_header();

if (get_theme_mod('intro-header-setting') == 'show'):?>
    <div class="dw-head-wrapper">
        <div class="dw-intro-page">
            <div class="<?php echo (get_theme_mod('intro_avatar_animation') == 'show') ? 'dw-logo' : 'dw-logo-woanim'; ?>">
                <?php if (get_custom_logo()) {
                    the_custom_logo();
                } ?>
            </div>
            <h1><?php bloginfo('name'); ?></h1>
            <h3><?php bloginfo('description') ?></h3>
            <div class="dw-home-link">
                <?php dw_social_links(); ?>
            </div>
        </div>
    </div>
    <div class="dw-post-hr"></div>
<?php endif; ?>
<div class="dw-wrapper">
    <div class="dw-post-area" id="main">
        <?php if (have_posts()): ?>
            <?php
            /* Start the Loop */
            while (have_posts()) : the_post(); ?>
                <?php if (!has_post_format('image')): ?>
                    <article class="dw-post" id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
                        <?php dw_post_thumbnail() ?>
                        <?php dw_post_title(); ?>
                        <div class="dw-post-details">
                            <?php dw_post_details(); ?>
                        </div>
                        <div class="dw-content">
                            <?php the_content(); ?>
                        </div>
                        <div class="dw-post-hr"></div>
                    </article>
                <?php else:
                    get_template_part('template-parts/content', 'image');
                endif; ?>
            <?php endwhile; ?>
        <?php else: ?>
            <p class="dw-align-center">
                <?php esc_html_e('There is no post to display.', 'ghasedak') ?>
            </p>
        <?php endif; ?>
    </div>
    <?php dw_pagination(); ?>
</div>
<?php get_footer(); ?>
